﻿using Infragistics.UltraChart.Core;
using Infragistics.UltraChart.Core.Primitives;
using Infragistics.UltraChart.Core.Util;
using Infragistics.UltraChart.Data;
using Infragistics.UltraChart.Shared.Styles;
using System;
using System.Collections.Generic;
using System.Data;
using System.Drawing;

namespace WebChart.ColumnChart
{
    public partial class Default : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            ultraChart.DataSource = GetColumnData();
            ultraChart.DataBind();

            ultraChart.Axis.Y.RangeType = AxisRangeType.Custom;
            ultraChart.Axis.Y.RangeMax = 15000.0;
            ultraChart.Width = 700;
        }

        private DataTable GetColumnData()
        {
            DataTable data = new DataTable();

            data.Columns.Add("Series Labels", typeof(string));
            data.Columns.Add("Column A", typeof(int));
            data.Columns.Add("Column B", typeof(int));
            data.Columns.Add("Column C", typeof(int));
            data.Columns.Add("Column D", typeof(int));

            data.Rows.Add(new Object[] { "Series A", 3500, 4000, 8000, 4000 });
            data.Rows.Add(new Object[] { "Series B", 3000, 6000, 4000, 5000 });
            data.Rows.Add(new Object[] { "Series C", 5000, 8000, 6000, 7000 });
            data.Rows.Add(new Object[] { "Series D", 7000, 10000, 7000, 7000 });

            return data;
        }

        protected void ultraChart_FillSceneGraph(object sender, Infragistics.UltraChart.Shared.Events.FillSceneGraphEventArgs e)
        {
            IAdvanceAxis yAxis = e.Grid["Y"] as IAdvanceAxis;
            IAdvanceAxis xAxis = e.Grid["X"] as IAdvanceAxis;

            IChartData chartData = e.ChartCore.GetCurrentDataRef();
            int rowCount = chartData.GetRowCount();
            int columnCount = chartData.GetColumnCount();
            var offset = 0.0;

            for (int i = 0; i < rowCount; i++)
            {
                var seriesOffset = offset;

                for (int j = 0; j < columnCount; j++)
                {
                    Text label = new Text();
                    var value = chartData.GetValue(i, j);

                    Point location = new Point((int)xAxis.Map(seriesOffset + j + 0.5), (int)yAxis.Map(value));
                    SizeF labelSize = Platform.GetStringSizePixels(value.ToString(), label.labelStyle.Font);
                    location.X -= (int)labelSize.Height / 2;
                    location.Y -= (int)labelSize.Width + 30;

                    label.labelStyle.Orientation = TextOrientation.Custom;
                    label.labelStyle.RotationAngle = 90;

                    FontFamily fontFamily = new FontFamily("Arial");
                    Font font = new Font(fontFamily, 9, FontStyle.Bold);
                    label.labelStyle.Font = font;

                    label.SetTextString("$ " + value.ToString());
                    label.bounds = new Rectangle(location, new Size((int)labelSize.Height, (int)labelSize.Height + 35));

                    e.SceneGraph.Add(label);

                    offset += 1.0;
                }
                offset += 1.0;
            }
        }
    }
}